; azDelete.SC       Revision 3   5/89
;
; This is not a commercial product, so  Zenreich Systems disclaims any liablity
; for it's use and consequences of decisions made on its use.
;
; I do publish a very useful commercial product:
;         ParaLex, the Documentor for Paradox Applications
; Contact Zenreich Systems at the address below for more information.
;
; Any questions or comments? I'd like to hear from you.
;     Alan Zenreich
;     Zenreich Systems
;     78 Fifth Avenue
;     New York, NY 10011
;     212-691-0170
;
; Problem: In interactive paradox, a user might want to be protected from
; accidentally deleting a record by inadvertantly pressing the delete key.
; The simple procedure outlined below puts up a menu that asks the user to
; confirm the deletion of the record.

; The approach uses a SETKEY, which reassignes the normal function of a
; keystroke (in this case the delete key).  The conditions governing the use
; in this case are simple.
; 1) Are we in a SYSMODE() that could cause the deletion of a record?
;    Using a SEARCH on a string containing applicable sysmodes is a technique
;    often overlooked, so I've applied it here.  If the sysmode cannot be found
;    within the string, it will return a 0.
; 2) Are we currently NOT in field view?
;    We check the value of FIELDVIEW()
; If both answers are TRUE, then lets put up a menu, if not, let the delete
; key behave normally.

; The setkey line is typically placed into an INIT script, so the delete key
; will not do unintentional record deletion.
; I am using Del.u() as a proc rather than a script, for performance reasons.

; You might want to assign autolib   (i.e., autolib="\\Paradox3\\Util") so the
; proc can be found easily, without the use of a readlib command.
; Paradox searches memory, and if autolib is not set, looks for a a library
; called Paradox.lib before giving up.  So you can read the library explicitly,
; or let Paradox try to find it.
;
; Examples listed below show cases where a readlib command is used if proc is
; not otherwise available.

; Lines are *commented out* because SETKEY must reside on a single line of code
;-------------------------------------------------------------------------
; SETKEY "Del"        ; redefine the delete key to evaluate effect
; SYNCCURSOR          ; if version 2 or above, keeps cursor from jumping to 0,0
;                     ; use only if it can fit on the setkey line
; IF ISFIELDVIEW() OR SEARCH(SYSMODE(),"CoEditDataEntryPassword")=0 THEN
    ; It is ok to pass the delete key through to paradox.
    ; (if you are not in one of the edit, coedit, dataentry, or Password modes,
    ; the del will used normally)
    ; The SEARCH is looking for the occurrence of the sysmode within the string.
;  Del  ; presses the delete key
; Else
   ;READLIB  "\\Paradox2\\Util" Del.u     ; example if proc is stored in lib
                                          ; file other than Paradox.lib in the
                                          ; current directory
;  Del.u()         ; run delete confirmation procedure
; ENDIF
;-------------------------------------------------------------------------
; The script above ***MUST*** be condensed onto one line to work with SETKEY:
;
; The following SETKEY will take effect in Edit, CoEdit, and DataEntry
; or Password modes.
; It also assumes that autolib is already set to the proper
; library, or there is no autolib and there is a file called Paradox.LIB

;-----------------------------------------------------------------------------------------------------------------------
                                                            ; more --> --> --> -->
SETKEY "Del" SYNCCURSOR IF ISFIELDVIEW() OR SEARCH(SYSMODE(),"CoEditDataEntryPassword")=0 THEN Del ELSE Del.u() ENDIF
;-----------------------------------------------------------------------------------------------------------------------
; The next example show a case where a readlib command is used if proc is
; not otherwise available.
; Because of the 132 character maximum of a setkey command, you may have to
; limit some features if you want to explicitly read it from a library , or
; build it into the proc itself

                                                            ; more --> --> --> -->
; SETKEY "Del" IF ISFIELDVIEW() OR SEARCH(SYSMODE(),"CoEdit")=0 Then Del ELSE readlib "\\Paradox2\\Util" Del.u Del.u() ENDIF


;-----------------------------------------------------------------------------------------------------------------------
; Now for the actual confirmation proc:

libname.a = "Paradox"             ;- Or whatever library you intend to use.

Proc Del.u()                   ;- remember that this proc only gets called when
  PRIVATE choice.a             ;- appropriate.
  BEEP                         ;- get the operator attention
  SHOWMENU                     ;- show options
  "Cancel":"Do not delete this record",
  "Delete":"OK to delete this record"
  TO choice.a
  IF choice.a = "Delete" THEN     ;- only delete the record if confirmed
    Del
  ENDIF
ENDPROC; Del.u
CREATELIB libname.a            ;- Needed only if library does not yet exist.
WRITELIB  libname.a  Del.u     ;- Write the proc into the library

